@@ -10,10 +10,7 @@ class ExtractTests(unittest.TestCase):
         snippet = StringIO(snippet)
         return list(extract_xml(snippet, None, None, None))
 
-    def testInvalidXML(self):
-        self.assertEqual(self.extract(""), [])
-
-    def testEmptyXml(self):
+    def test_empty_xml(self):
         self.assertEqual(self.extract("<html/>"), [])
 
     def test_attributes_plain(self):
@@ -284,3 +281,11 @@ class ExtractTests(unittest.TestCase):
                 """
         self.assertEqual(self.extract(snippet),
                 [(3, None, u"foo", [u'Default: blah'])])
+
+    def test_abort_on_invalid_xml(self):
+        snippet = """\
+                <html>
+                  <h2 id=bar>Foo</h2>
+                </html>
+                """
+        self.assertRaises(SystemExit, self.extract, snippet)
